@@ -4,7 +4,6 @@ from typing import Dict, Optional, Any
 from kaizen.llms.prompts.general_prompts import BASIC_SYSTEM_PROMPT
 from kaizen.utils.config import ConfigData
 from litellm import Router
-import asyncio
 import logging
 
 
@@ -103,16 +102,17 @@ class LLMProvider:
         if "temperature" not in custom_model:
             custom_model["temperature"] = self.default_temperature
 
-        # TODO: Add better way to manage this async calls
-        loop = asyncio.get_event_loop()
-        response = loop.run_until_complete(
-            self.router_acompletion(messages, user, custom_model)
+        response = self.provider.completion(
+            messages=messages, user=user, **custom_model
         )
         return response["choices"][0]["message"]["content"], response["usage"]
 
     def is_inside_token_limit(self, PROMPT: str, percentage: float = 0.8) -> bool:
-        # TODO: Also include system prompt
-        messages = [{"user": "role", "content": PROMPT}]
+        # Include system prompt in token calculation
+        messages = [
+            {"role": "system", "content": self.system_prompt},
+            {"role": "user", "content": PROMPT},
+        ]
         token_count = litellm.token_counter(model=self.model, messages=messages)
         max_tokens = litellm.get_max_tokens(self.model)
         return token_count <= max_tokens * percentage
